# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Metrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'scope': 'str',
        'id': 'str',
        'period': 'float',
        'samples': 'list[MetricsSample]'
    }

    attribute_map = {
        'scope': 'scope',
        'id': 'id',
        'period': 'period',
        'samples': 'samples'
    }

    def __init__(self, scope=None, id=None, period=None, samples=None):  # noqa: E501
        """Metrics - a model defined in Swagger"""  # noqa: E501
        self._scope = None
        self._id = None
        self._period = None
        self._samples = None
        self.discriminator = None
        if scope is not None:
            self.scope = scope
        if id is not None:
            self.id = id
        if period is not None:
            self.period = period
        if samples is not None:
            self.samples = samples

    @property
    def scope(self):
        """Gets the scope of this Metrics.  # noqa: E501


        :return: The scope of this Metrics.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this Metrics.


        :param scope: The scope of this Metrics.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def id(self):
        """Gets the id of this Metrics.  # noqa: E501


        :return: The id of this Metrics.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Metrics.


        :param id: The id of this Metrics.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def period(self):
        """Gets the period of this Metrics.  # noqa: E501


        :return: The period of this Metrics.  # noqa: E501
        :rtype: float
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this Metrics.


        :param period: The period of this Metrics.  # noqa: E501
        :type: float
        """

        self._period = period

    @property
    def samples(self):
        """Gets the samples of this Metrics.  # noqa: E501


        :return: The samples of this Metrics.  # noqa: E501
        :rtype: list[MetricsSample]
        """
        return self._samples

    @samples.setter
    def samples(self, samples):
        """Sets the samples of this Metrics.


        :param samples: The samples of this Metrics.  # noqa: E501
        :type: list[MetricsSample]
        """

        self._samples = samples

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Metrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Metrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
